|image0| |image1|

youtube2mp3
===========
a wrapper to simplify youtube downloads with `youtube-dl <https://github.com/rg3/youtube-dl>`_

downloaded files will be tagged with `mutagen <https://pypi.python.org/pypi/mutagen>`_

installation
------------
with pip
""""""""
pip install youtube2mp3

manual install
""""""""""""""
python setup.py build

python setup.py install

usage
-----
youtube2mp3 [options] arg1 arg2

see *youtube2mp3 -h* for more information

development
-----------
We use pipenv for development environment - *pip install pipenv*

create virtual environment
*pipenv --two*

install dependencies
*pipenv install*

.. |image0| image:: https://pyup.io/repos/github/pfitzer/youtube2mp3/shield.svg
     :target: https://pyup.io/repos/github/pfitzer/youtube2mp3/
     :alt: Updates

.. |image1| image:: https://pyup.io/repos/github/pfitzer/youtube2mp3/python-3-shield.svg
     :target: https://pyup.io/repos/github/pfitzer/youtube2mp3/
     :alt: Python 3